==> coreader-0.0.4.tar.gz: coreader-0.0.4/setup.py <==
from setuptools import setup, find_packages

setup(
    name='CoReader',
    version='0.0.4',
    author='4White9264',
    author_email='your_email@example.com',
    description='A package for self-modeling based diagnosis of software-defined networks',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='https://github.com/your_username/CoReader',
    packages=find_packages(where='src'),
    package_dir={'': 'src'},
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
    install_requires=[
        'CoReader==0.0.1',
        'alabaster==1.0.0',
        'anyio==4.6.2.post1',
        'arrow==1.3.0',
        'attrs==24.2.0',
        'babel==2.16.0',
        'beautifulsoup4==4.12.3',
        'bibtexparser==1.4.2',
        'build==1.2.2.post1',
        'certifi==2024.8.30',
        'cffi==1.17.1',
        'charset-normalizer==3.4.0',
        'ci-info==0.3.0',
        'click==8.1.7',
        'configobj==5.0.9',
        'configparser==7.1.0',
        'CoReader @ file:///workspaces/CoReader/packaging_tutorial',
        'cryptography==43.0.3',
        'Deprecated==1.2.15',
        'docutils==0.21.2',
        'etelemetry==0.3.1',
        'fake-useragent==1.5.1',
        'filelock==3.16.1',
        'fitz==0.0.1.dev2',
        'free_proxy==1.1.3',
        'google_search_results==2.4.2',
        'h11==0.14.0',
        'httpcore==1.0.7',
        'httplib2==0.22.0',
        'httpx==0.27.2',
        'idna==3.10',
        'imagesize==1.4.1',
        'importlib_metadata==8.5.0',
        'isodate==0.6.1',
        'jaraco.classes==3.4.0',
        'jaraco.context==6.0.1',
        'jaraco.functools==4.1.0',
        'jeepney==0.8.0',
        'Jinja2==3.1.4',
        'keyring==25.5.0',
        'looseversion==1.3.0',
        'lxml==5.3.0',
        'markdown-it-py==3.0.0',
        'MarkupSafe==3.0.2',
        'mdurl==0.1.2',
        'more-itertools==10.5.0',
        'networkx==3.4.2',
        'nh3==0.2.18',
        'nibabel==5.3.2',
        'nipype==1.9.0',
        'numpy==1.26.4',
        'outcome==1.3.0.post0',
        'packaging==24.2',
        'pandas==2.2.3',
        'pathlib==1.0.1',
        'pkginfo==1.10.0',
        'prov==2.0.1',
        'puremagic==1.28',
        'pycparser==2.22',
        'pydot==3.0.2',
        'Pygments==2.18.0',
        'PyMuPDF==1.24.13',
        'pyparsing==3.2.0',
        'pyproject_hooks==1.2.0',
        'PySocks==1.7.1',
        'python-dateutil==2.9.0.post0',
        'python-dotenv==1.0.1',
        'pytz==2024.2',
        'pyxnat==1.6.2',
        'rdflib==6.3.2',
        'readme_renderer==44.0',
        'requests==2.32.3',
        'requests-toolbelt==1.0.0',
        'rfc3986==2.0.0',
        'rich==13.9.4',
        'scholarly==1.7.11',
        'scipy==1.14.1',
        'SecretStorage==3.3.3',
        'selenium==4.26.1',
        'serpapi==0.1.5',
        'setuptools==75.5.0',
        'simplejson==3.19.3',
        'six==1.16.0',
        'sniffio==1.3.1',
        'snowballstemmer==2.2.0',
        'sortedcontainers==2.4.0',
        'soupsieve==2.6',
        'Sphinx==8.1.3',
        'sphinx-rtd-theme==3.0.2',
        'sphinxcontrib-applehelp==2.0.0',
        'sphinxcontrib-devhelp==2.0.0',
        'sphinxcontrib-htmlhelp==2.1.0',
        'sphinxcontrib-jquery==4.1',
        'sphinxcontrib-jsmath==1.0.1',
        'sphinxcontrib-qthelp==2.0.0',
        'sphinxcontrib-serializinghtml==2.0.0',
        'toml==0.10.2',
        'traits==6.4.3',
        'trio==0.27.0',
        'trio-websocket==0.11.1',
        'twine==5.1.1',
        'types-python-dateutil==2.9.0.20241003',
        'typing_extensions==4.12.2',
        'tzdata==2024.2',
        'urllib3==2.2.3',
        'websocket-client==1.8.0',
        'wrapt==1.16.0',
        'wsproto==1.2.0',
        'zipp==3.21.0'
    ],
)

==> coreader-0.0.5.tar.gz: coreader-0.0.5/setup.py <==
from setuptools import setup, find_packages

setup(
    name='CoReader',
    version='0.0.5',
    author='4White9264',
    author_email='yansheng_chen9264@163.com',
    description='CoReader, AI Research Paper Assistant',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='https://github.com/4White9264/CoReader',
    packages=find_packages(where='src/_package_CoReader_Poly'),
    package_dir={'': '/workspaces/CoReader/packaging_tutorial/src/_package_CoReader_Poly'},
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.8',
    install_requires=[
        'CoReader==0.0.1',
        'alabaster==1.0.0',
        'anyio==4.6.2.post1',
        'arrow==1.3.0',
        'attrs==24.2.0',
        'babel==2.16.0',
        'beautifulsoup4==4.12.3',
        'bibtexparser==1.4.2',
        'build==1.2.2.post1',
        'certifi==2024.8.30',
        'cffi==1.17.1',
        'charset-normalizer==3.4.0',
        'ci-info==0.3.0',
        'click==8.1.7',
        'configobj==5.0.9',
        'configparser==7.1.0',
        'CoReader @ file:///workspaces/CoReader/packaging_tutorial',
        'cryptography==43.0.3',
        'Deprecated==1.2.15',
        'docutils==0.21.2',
        'etelemetry==0.3.1',
        'fake-useragent==1.5.1',
        'filelock==3.16.1',
        'fitz==0.0.1.dev2',
        'free_proxy==1.1.3',
        'google_search_results==2.4.2',
        'h11==0.14.0',
        'httpcore==1.0.7',
        'httplib2==0.22.0',
        'httpx==0.27.2',
        'idna==3.10',
        'imagesize==1.4.1',
        'importlib_metadata==8.5.0',
        'isodate==0.6.1',
        'jaraco.classes==3.4.0',
        'jaraco.context==6.0.1',
        'jaraco.functools==4.1.0',
        'jeepney==0.8.0',
        'Jinja2==3.1.4',
        'keyring==25.5.0',
        'looseversion==1.3.0',
        'lxml==5.3.0',
        'markdown-it-py==3.0.0',
        'MarkupSafe==3.0.2',
        'mdurl==0.1.2',
        'more-itertools==10.5.0',
        'networkx==3.4.2',
        'nh3==0.2.18',
        'nibabel==5.3.2',
        'nipype==1.9.0',
        'numpy==1.26.4',
        'outcome==1.3.0.post0',
        'packaging==24.2',
        'pandas==2.2.3',
        'pathlib==1.0.1',
        'pkginfo==1.10.0',
        'prov==2.0.1',
        'puremagic==1.28',
        'pycparser==2.22',
        'pydot==3.0.2',
        'Pygments==2.18.0',
        'PyMuPDF==1.24.13',
        'pyparsing==3.2.0',
        'pyproject_hooks==1.2.0',
        'PySocks==1.7.1',
        'python-dateutil==2.9.0.post0',
        'python-dotenv==1.0.1',
        'pytz==2024.2',
        'pyxnat==1.6.2',
        'rdflib==6.3.2',
        'readme_renderer==44.0',
        'requests==2.32.3',
        'requests-toolbelt==1.0.0',
        'rfc3986==2.0.0',
        'rich==13.9.4',
        'scholarly==1.7.11',
        'scipy==1.14.1',
        'SecretStorage==3.3.3',
        'selenium==4.26.1',
        'serpapi==0.1.5',
        'setuptools==75.5.0',
        'simplejson==3.19.3',
        'six==1.16.0',
        'sniffio==1.3.1',
        'snowballstemmer==2.2.0',
        'sortedcontainers==2.4.0',
        'soupsieve==2.6',
        'Sphinx==8.1.3',
        'sphinx-rtd-theme==3.0.2',
        'sphinxcontrib-applehelp==2.0.0',
        'sphinxcontrib-devhelp==2.0.0',
        'sphinxcontrib-htmlhelp==2.1.0',
        'sphinxcontrib-jquery==4.1',
        'sphinxcontrib-jsmath==1.0.1',
        'sphinxcontrib-qthelp==2.0.0',
        'sphinxcontrib-serializinghtml==2.0.0',
        'toml==0.10.2',
        'traits==6.4.3',
        'trio==0.27.0',
        'trio-websocket==0.11.1',
        'twine==5.1.1',
        'types-python-dateutil==2.9.0.20241003',
        'typing_extensions==4.12.2',
        'tzdata==2024.2',
        'urllib3==2.2.3',
        'websocket-client==1.8.0',
        'wrapt==1.16.0',
        'wsproto==1.2.0',
        'zipp==3.21.0'
    ],
)
